##  Scheduling Changes for Fact Sheet Relations
When scheduling changes for fact sheet relations, you can create or remove particular relations or use transformation templates to create or remove relations.
To schedule a change for a relation, follow these steps:
  1. Hover over the relevant subsection and click **Schedule Change**.
  2. In the overlay, select one of the following actions based on your needs.
a) Create Relation
b) Remove Relations
c) Select a relevant transformation template under Use a Transformation Template.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa73aaa98299b4f23b5b032b310c64f6b_LowRes.png)
Scheduling Changes for Fact Sheet Relations
Follow the corresponding instructions for your chosen action:
### Creating Relations
  1. Select the fact sheet to which to establish the new relation.
  2. Click Scheduled Change to open the settings overlay.
  3. Under Initiative, search for and select an existing initiative fact sheet. If no fact sheet exists, create a new one to associate the change with.
  4. Under ,Transformation Name choose an existing transformation item or create a new one to group the change under.
  5. Under Effective Date of Change, enter a date for when the change should take place.
  6. Click Save.


### Removing Relations
  1. Check the boxes next to the relations that you want to remove.
  2. Click Selected Fact Sheets or Select All to remove all relations.
  3. Click Scheduled Change to open the settings overlay.
  4. Under Initiative, search for and select an existing initiative fact sheet. If no fact sheet exists, create a new one to associate the change with.
  5. Under Transformation Name, choose an existing transformation item or create a new one to group the change under.
  6. Under Effective Date of Change, enter a date for when the change should take place.
  7. Click Save.


### Using a Transformation Template
  1. Fill in all required fields in the selected transformation template.
  2. Click Save.
